@@ -36,7 +36,7 @@ def is_simple_callable(obj):
     # Bail early since we cannot inspect built-in function signatures.
     if inspect.isbuiltin(obj):
         raise ValueError(
-            'Built-in function signatures are not inspectable. '
+            'Built-in function signatures are not injectable. '
             'Wrap the function call in a simple, pure Python function.')
 
     if not (inspect.isfunction(obj) or inspect.ismethod(obj) or isinstance(obj, functools.partial)):
@@ -106,15 +106,18 @@ class BaseField(object):
 
     ALLOWED_TYPES = None
 
-    def __init__(self, initial=Empty, proto_field=None, default=None, custom=False, context=None, **kwargs):
+    initial = None
+
+    def __init__(self, initial=Empty, proto_field=None, default=None, data_field=None, custom=False, context=None):
         # Increase the auto creation counter
         self._auto_creation_counter = BaseField._auto_creation_counter
         BaseField._auto_creation_counter += 1
 
-        self.initial = initial
+        self.initial = self.initial if (initial is Empty) else initial
         self.proto_field = proto_field
         self.default = default
         self.custom = custom
+        self.data_field = data_field
         self.context = context
 
         # These are set up by `.bind()` when the field is added to a serializer.
@@ -123,8 +126,8 @@ class BaseField(object):
         self.source = None
         self.attributes = None
 
-        self.meta = getattr(self, 'meta', None)
-        self.pb = self.meta.get('schema', None) if self.meta else None
+        self.meta = getattr(self, 'Meta', None)
+        self.pb = getattr(self.meta, 'schema', None) if self.meta else None
 
     def bind(self, field_name, parent):
         self.field_name = field_name
@@ -151,8 +154,8 @@ class BaseField(object):
         # convert the dictionary to mapping to make it easier to work with
         dictionary = DictMapper(dictionary) if isinstance(dictionary, dict) else dictionary
         # we convert `_id` to `id` to prevent `_id` from being accessed as a private field
-        if '_id' in dictionary and isinstance(dictionary, dict):
-            dictionary['id'] = dictionary.pop('_id')
+        if self.data_field and isinstance(dictionary, dict):
+            dictionary[self.field_name] = dictionary.pop(self.data_field)
 
         if self.custom:
             fill_method = getattr(instance, f'get_custom_{self.field_name}', None)
@@ -365,15 +368,19 @@ class CustomField(BaseField):
 
 class ListField(BaseField):
 
-    ALLOWED_TYPES = ['CharField', 'DateTimeField', 'IntField', 'ObjectIdField', 'CustomField', 'BooleanField', 'FloatField']
+    ALLOWED_TYPES = [
+        'CharField', 'DateTimeField', 'IntField',
+        'ObjectIdField', 'CustomField', 'BooleanField',
+        'FloatField'
+    ]
 
-    def __init__(self, type=None, **kwargs):
-        self.type = type
-        if type and type.__class__.__name__ not in self.ALLOWED_TYPES:
+    def __init__(self, child=None, **kwargs):
+        self.type = child
+        if child and child.__class__.__name__ not in self.ALLOWED_TYPES:
             raise ValueError(
                 'type {!r} is not allowed for {!r}. '
                 'Allowed types are: {}'.format(
-                    type.__class__.__name__,
+                    child.__class__.__name__,
                     self.__class__.__name__,
                     ', '.join(self.ALLOWED_TYPES)
                 )
@@ -403,13 +410,13 @@ class DictField(BaseField):
 
     ALLOWED_TYPES = ['ListField']
 
-    def __init__(self, type=None, **kwargs):
-        self.type = type
-        if type and type.__class__.__name__ not in self.ALLOWED_TYPES:
+    def __init__(self, child=None, **kwargs):
+        self.type = child
+        if child and child.__class__.__name__ not in self.ALLOWED_TYPES:
             raise ValueError(
                 'type {!r} is not allowed for {!r}. '
                 'Allowed types are: {}'.format(
-                    type.__class__.__name__,
+                    child.__class__.__name__,
                     self.__class__.__name__,
                     ', '.join(self.ALLOWED_TYPES)
                 )
@@ -444,8 +451,8 @@ class DictField(BaseField):
 
 class DateTimeField(BaseField):
 
-    def __init__(self, format='%Y-%m-%dT%H:%M:%S', **kwargs):
-        self.format = format
+    def __init__(self, fmt='%Y-%m-%dT%H:%M:%S', **kwargs):
+        self.format = fmt
         super().__init__(**kwargs)
 
     def to_internal_value(self, data):
@@ -477,13 +484,13 @@ class TimestampField(BaseField):
 
     ALLOWED_TYPES = ['IntField', 'CharField', 'FloatField']
 
-    def __init__(self, type=None, **kwargs):
-        self.type = IntField() if type is None else type
-        if type and type.__class__.__name__ not in self.ALLOWED_TYPES:
+    def __init__(self, child=None, **kwargs):
+        self.type = IntField() if child is None else child
+        if child and child.__class__.__name__ not in self.ALLOWED_TYPES:
             raise ValueError(
                 'type {!r} is not allowed for {!r}. '
                 'Allowed types are: {}'.format(
-                    type.__class__.__name__,
+                    child.__class__.__name__,
                     self.__class__.__name__,
                     ', '.join(self.ALLOWED_TYPES)
                 )
