@@ -1,7 +1,7 @@
 import copy
 from functools import cached_property
 
-from google.protobuf.json_format import ParseDict
+from google.protobuf.json_format import ParseDict # noqa
 
 from mgo_serializer.fields import BaseField, Empty, set_value
 from mgo_serializer.exceptions import ValidationError
@@ -91,7 +91,7 @@ class BaseSerializer(BaseField):
             msg = (
                 'When a serializer is passed a `data` keyword argument you '
                 'must call `.is_valid()` before attempting to access the '
-                'serialized `.data` representation.\n'
+                'serialized `.data` or `.protobuf` representation.\n'
                 'You should either call `.is_valid()` first, '
                 'or access `.initial_data` instead.'
             )
@@ -99,7 +99,9 @@ class BaseSerializer(BaseField):
 
         if not hasattr(self, '_data'):
             if self.instance is not None and not getattr(self, '_errors', None):
-                self._data = self.to_representation(self.instance)
+                self._data = self.to_representation(
+                    self.to_internal_value(self.instance)
+                )
             elif hasattr(self, '_validated_data') and not getattr(self, '_errors', None):
                 self._data = self.to_representation(self.validated_data)
             else:
@@ -116,18 +118,19 @@ class BaseSerializer(BaseField):
         :rtype: list
         """
 
-        text = 'Protobuf is not defined in {!r} serializer. ' \
-               'You can define it in meta variable with `schema` key.'
-
         if hasattr(self, 'child') and not self.child.pb:
-            raise AttributeError(text.format(self.child.__class__.__name__))
-        elif not self.pb:
-            raise AttributeError(text.format(self.__class__.__name__))
+            raise AttributeError(
+                'Protobuf is not defined in {!r} serializer. '
+                'You can define it in MetaClass with `schema` key.'.format(self.child.__class__.__name__)
+            )
 
-        self._protobuf = self.to_representation(self.validated_data)
         protobuf_list = []
-        for data in self._protobuf:
-            protobuf_list.append(self.to_protobuf(data))
+        self._protobuf = self.data
+        if isinstance(self._protobuf, list):
+            for item in self._protobuf:
+                protobuf_list.append(self.to_protobuf(item))
+        else:
+            return self.to_protobuf(self._protobuf)
 
         return protobuf_list
 
@@ -140,7 +143,7 @@ class BaseSerializer(BaseField):
 
     @property
     def validated_data(self):
-        if not hasattr(self, '_validated_data'):
+        if hasattr(self, 'initial_data') and not hasattr(self, '_validated_data'):
             msg = 'You must call `.is_valid()` before accessing `.validated_data`.'
             raise AssertionError(msg)
         return self._validated_data
@@ -188,7 +191,8 @@ class ListSerializer(BaseSerializer):
     def to_protobuf(self, data):
         return self.child.to_protobuf(data)
 
-    def validate(self, attrs):
+    @staticmethod
+    def validate(attrs):
         return attrs
 
     def run_validation(self, data=Empty):
@@ -280,12 +284,12 @@ class Serializer(BaseSerializer, metaclass=SerializerMetaclass):
         fields = self._readable_fields
 
         for field in fields:
-            clean_method = getattr(self, 'clean_' + field.field_name, None)
+            validate_method = getattr(self, 'validate_' + field.field_name, None)
             primitive_value = field.get_value(data, self)
             try:
                 validated_value = field.run_validation(primitive_value)
-                if clean_method:
-                    validated_value = clean_method(primitive_value)
+                if validate_method:
+                    validated_value = validate_method(primitive_value)
             except ValidationError as e:
                 errors[field.field_name] = 'ERROR: ' + str(e)
             else:
